==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/TelephonyChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Direct Line channel.
 * @property apiConfigurations The list of Telephony api configuration
 * @property cognitiveServiceRegion The extensionKey2
 * @property cognitiveServiceSubscriptionKey The extensionKey1
 * @property defaultLocale The default locale of the channel
 * @property isEnabled Whether the channel is enabled
 * @property phoneNumbers The list of Telephony phone numbers
 * @property premiumSKU The premium SKU applied to the channel
 */
public data class TelephonyChannelPropertiesArgs(
    public val apiConfigurations: Output<List<TelephonyChannelResourceApiConfigurationArgs>>? = null,
    public val cognitiveServiceRegion: Output<String>? = null,
    public val cognitiveServiceSubscriptionKey: Output<String>? = null,
    public val defaultLocale: Output<String>? = null,
    public val isEnabled: Output<Boolean>? = null,
    public val phoneNumbers: Output<List<TelephonyPhoneNumbersArgs>>? = null,
    public val premiumSKU: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs.builder()
            .apiConfigurations(
                apiConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .cognitiveServiceRegion(cognitiveServiceRegion?.applyValue({ args0 -> args0 }))
            .cognitiveServiceSubscriptionKey(cognitiveServiceSubscriptionKey?.applyValue({ args0 -> args0 }))
            .defaultLocale(defaultLocale?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled?.applyValue({ args0 -> args0 }))
            .phoneNumbers(
                phoneNumbers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .premiumSKU(premiumSKU?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TelephonyChannelPropertiesArgs].
 */
@PulumiTagMarker
public class TelephonyChannelPropertiesArgsBuilder internal constructor() {
    private var apiConfigurations: Output<List<TelephonyChannelResourceApiConfigurationArgs>>? = null

    private var cognitiveServiceRegion: Output<String>? = null

    private var cognitiveServiceSubscriptionKey: Output<String>? = null

    private var defaultLocale: Output<String>? = null

    private var isEnabled: Output<Boolean>? = null

    private var phoneNumbers: Output<List<TelephonyPhoneNumbersArgs>>? = null

    private var premiumSKU: Output<String>? = null

    /**
     * @param value The list of Telephony api configuration
     */
    @JvmName("ascnnmyjoqndtcln")
    public suspend
    fun apiConfigurations(`value`: Output<List<TelephonyChannelResourceApiConfigurationArgs>>) {
        this.apiConfigurations = value
    }

    @JvmName("smjuhkwukmcweqnv")
    public suspend fun apiConfigurations(
        vararg
        values: Output<TelephonyChannelResourceApiConfigurationArgs>,
    ) {
        this.apiConfigurations = Output.all(values.asList())
    }

    /**
     * @param values The list of Telephony api configuration
     */
    @JvmName("vcbnytljxqlbhave")
    public suspend
    fun apiConfigurations(values: List<Output<TelephonyChannelResourceApiConfigurationArgs>>) {
        this.apiConfigurations = Output.all(values)
    }

    /**
     * @param value The extensionKey2
     */
    @JvmName("ycpgekfgbjokvqvt")
    public suspend fun cognitiveServiceRegion(`value`: Output<String>) {
        this.cognitiveServiceRegion = value
    }

    /**
     * @param value The extensionKey1
     */
    @JvmName("aroyfljxkyngdqiu")
    public suspend fun cognitiveServiceSubscriptionKey(`value`: Output<String>) {
        this.cognitiveServiceSubscriptionKey = value
    }

    /**
     * @param value The default locale of the channel
     */
    @JvmName("lxfnvddopodmveri")
    public suspend fun defaultLocale(`value`: Output<String>) {
        this.defaultLocale = value
    }

    /**
     * @param value Whether the channel is enabled
     */
    @JvmName("vuhxptgnjwoicnos")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value The list of Telephony phone numbers
     */
    @JvmName("iwctxmmtpgikswwf")
    public suspend fun phoneNumbers(`value`: Output<List<TelephonyPhoneNumbersArgs>>) {
        this.phoneNumbers = value
    }

    @JvmName("lghdjsclmhdpjihf")
    public suspend fun phoneNumbers(vararg values: Output<TelephonyPhoneNumbersArgs>) {
        this.phoneNumbers = Output.all(values.asList())
    }

    /**
     * @param values The list of Telephony phone numbers
     */
    @JvmName("ldetrgnepjlpnyem")
    public suspend fun phoneNumbers(values: List<Output<TelephonyPhoneNumbersArgs>>) {
        this.phoneNumbers = Output.all(values)
    }

    /**
     * @param value The premium SKU applied to the channel
     */
    @JvmName("mmngvnpwlltbrxly")
    public suspend fun premiumSKU(`value`: Output<String>) {
        this.premiumSKU = value
    }

    /**
     * @param value The list of Telephony api configuration
     */
    @JvmName("fyxrxlsnymfrqwer")
    public suspend
    fun apiConfigurations(`value`: List<TelephonyChannelResourceApiConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apiConfigurations = mapped
    }

    /**
     * @param argument The list of Telephony api configuration
     */
    @JvmName("bupugecsfcwecqey")
    public suspend
    fun apiConfigurations(argument: List<suspend TelephonyChannelResourceApiConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TelephonyChannelResourceApiConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.apiConfigurations = mapped
    }

    /**
     * @param argument The list of Telephony api configuration
     */
    @JvmName("hrwhnahhuelcusun")
    public suspend fun apiConfigurations(
        vararg
        argument: suspend TelephonyChannelResourceApiConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TelephonyChannelResourceApiConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.apiConfigurations = mapped
    }

    /**
     * @param argument The list of Telephony api configuration
     */
    @JvmName("fkjopqrrajqoucpo")
    public suspend
    fun apiConfigurations(argument: suspend TelephonyChannelResourceApiConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            TelephonyChannelResourceApiConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.apiConfigurations = mapped
    }

    /**
     * @param values The list of Telephony api configuration
     */
    @JvmName("qqoyhloadqvsbeyv")
    public suspend fun apiConfigurations(
        vararg
        values: TelephonyChannelResourceApiConfigurationArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.apiConfigurations = mapped
    }

    /**
     * @param value The extensionKey2
     */
    @JvmName("ynvqmnnuixiojfqe")
    public suspend fun cognitiveServiceRegion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cognitiveServiceRegion = mapped
    }

    /**
     * @param value The extensionKey1
     */
    @JvmName("ayccdrugexsxhujx")
    public suspend fun cognitiveServiceSubscriptionKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cognitiveServiceSubscriptionKey = mapped
    }

    /**
     * @param value The default locale of the channel
     */
    @JvmName("ojvvlidrsdtrwxdr")
    public suspend fun defaultLocale(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultLocale = mapped
    }

    /**
     * @param value Whether the channel is enabled
     */
    @JvmName("fjoyutgevncbpywc")
    public suspend fun isEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value The list of Telephony phone numbers
     */
    @JvmName("jwsdghwnrmxmbjij")
    public suspend fun phoneNumbers(`value`: List<TelephonyPhoneNumbersArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.phoneNumbers = mapped
    }

    /**
     * @param argument The list of Telephony phone numbers
     */
    @JvmName("icikcljgdoaxfjew")
    public suspend
    fun phoneNumbers(argument: List<suspend TelephonyPhoneNumbersArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TelephonyPhoneNumbersArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.phoneNumbers = mapped
    }

    /**
     * @param argument The list of Telephony phone numbers
     */
    @JvmName("mcdyxapyjbmmowge")
    public suspend fun phoneNumbers(
        vararg
        argument: suspend TelephonyPhoneNumbersArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TelephonyPhoneNumbersArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.phoneNumbers = mapped
    }

    /**
     * @param argument The list of Telephony phone numbers
     */
    @JvmName("guetoxxotoskoict")
    public suspend fun phoneNumbers(argument: suspend TelephonyPhoneNumbersArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TelephonyPhoneNumbersArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.phoneNumbers = mapped
    }

    /**
     * @param values The list of Telephony phone numbers
     */
    @JvmName("kwoyjghyauhjgnkf")
    public suspend fun phoneNumbers(vararg values: TelephonyPhoneNumbersArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.phoneNumbers = mapped
    }

    /**
     * @param value The premium SKU applied to the channel
     */
    @JvmName("wanksbqiblrklsal")
    public suspend fun premiumSKU(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.premiumSKU = mapped
    }

    internal fun build(): TelephonyChannelPropertiesArgs = TelephonyChannelPropertiesArgs(
        apiConfigurations = apiConfigurations,
        cognitiveServiceRegion = cognitiveServiceRegion,
        cognitiveServiceSubscriptionKey = cognitiveServiceSubscriptionKey,
        defaultLocale = defaultLocale,
        isEnabled = isEnabled,
        phoneNumbers = phoneNumbers,
        premiumSKU = premiumSKU,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/TelephonyChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Direct Line channel.
 * @property apiConfigurations The list of Telephony api configuration
 * @property cognitiveServiceRegion The extensionKey2
 * @property cognitiveServiceSubscriptionKey The extensionKey1
 * @property defaultLocale The default locale of the channel
 * @property isEnabled Whether the channel is enabled
 * @property phoneNumbers The list of Telephony phone numbers
 * @property premiumSKU The premium SKU applied to the channel
 */
public data class TelephonyChannelPropertiesArgs(
    public val apiConfigurations: Output<List<TelephonyChannelResourceApiConfigurationArgs>>? = null,
    public val cognitiveServiceRegion: Output<String>? = null,
    public val cognitiveServiceSubscriptionKey: Output<String>? = null,
    public val defaultLocale: Output<String>? = null,
    public val isEnabled: Output<Boolean>? = null,
    public val phoneNumbers: Output<List<TelephonyPhoneNumbersArgs>>? = null,
    public val premiumSKU: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.TelephonyChannelPropertiesArgs.builder()
            .apiConfigurations(
                apiConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .cognitiveServiceRegion(cognitiveServiceRegion?.applyValue({ args0 -> args0 }))
            .cognitiveServiceSubscriptionKey(cognitiveServiceSubscriptionKey?.applyValue({ args0 -> args0 }))
            .defaultLocale(defaultLocale?.applyValue({ args0 -> args0 }))
            .isEnabled(isEnabled?.applyValue({ args0 -> args0 }))
            .phoneNumbers(
                phoneNumbers?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .premiumSKU(premiumSKU?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TelephonyChannelPropertiesArgs].
 */
@PulumiTagMarker
public class TelephonyChannelPropertiesArgsBuilder internal constructor() {
    private var apiConfigurations: Output<List<TelephonyChannelResourceApiConfigurationArgs>>? = null

    private var cognitiveServiceRegion: Output<String>? = null

    private var cognitiveServiceSubscriptionKey: Output<String>? = null

    private var defaultLocale: Output<String>? = null

    private var isEnabled: Output<Boolean>? = null

    private var phoneNumbers: Output<List<TelephonyPhoneNumbersArgs>>? = null

    private var premiumSKU: Output<String>? = null

    /**
     * @param value The list of Telephony api configuration
     */
    @JvmName("oyvrqvqfwnbuadlf")
    public suspend
    fun apiConfigurations(`value`: Output<List<TelephonyChannelResourceApiConfigurationArgs>>) {
        this.apiConfigurations = value
    }

    @JvmName("yfpllmdhhrqmkkvo")
    public suspend fun apiConfigurations(
        vararg
        values: Output<TelephonyChannelResourceApiConfigurationArgs>,
    ) {
        this.apiConfigurations = Output.all(values.asList())
    }

    /**
     * @param values The list of Telephony api configuration
     */
    @JvmName("rkvktxmgaymertmb")
    public suspend
    fun apiConfigurations(values: List<Output<TelephonyChannelResourceApiConfigurationArgs>>) {
        this.apiConfigurations = Output.all(values)
    }

    /**
     * @param value The extensionKey2
     */
    @JvmName("awbtgeuutrtmusbf")
    public suspend fun cognitiveServiceRegion(`value`: Output<String>) {
        this.cognitiveServiceRegion = value
    }

    /**
     * @param value The extensionKey1
     */
    @JvmName("lsswyqwkfvghmrla")
    public suspend fun cognitiveServiceSubscriptionKey(`value`: Output<String>) {
        this.cognitiveServiceSubscriptionKey = value
    }

    /**
     * @param value The default locale of the channel
     */
    @JvmName("wwecaaiolnaddmnn")
    public suspend fun defaultLocale(`value`: Output<String>) {
        this.defaultLocale = value
    }

    /**
     * @param value Whether the channel is enabled
     */
    @JvmName("qeigpxwsjxrqthfk")
    public suspend fun isEnabled(`value`: Output<Boolean>) {
        this.isEnabled = value
    }

    /**
     * @param value The list of Telephony phone numbers
     */
    @JvmName("iianuinxdrqwebwt")
    public suspend fun phoneNumbers(`value`: Output<List<TelephonyPhoneNumbersArgs>>) {
        this.phoneNumbers = value
    }

    @JvmName("lopkfeipkelvvria")
    public suspend fun phoneNumbers(vararg values: Output<TelephonyPhoneNumbersArgs>) {
        this.phoneNumbers = Output.all(values.asList())
    }

    /**
     * @param values The list of Telephony phone numbers
     */
    @JvmName("bnyxssvacfyjdirt")
    public suspend fun phoneNumbers(values: List<Output<TelephonyPhoneNumbersArgs>>) {
        this.phoneNumbers = Output.all(values)
    }

    /**
     * @param value The premium SKU applied to the channel
     */
    @JvmName("vqujskbxmamngbif")
    public suspend fun premiumSKU(`value`: Output<String>) {
        this.premiumSKU = value
    }

    /**
     * @param value The list of Telephony api configuration
     */
    @JvmName("dcbbqnigsywoxryg")
    public suspend
    fun apiConfigurations(`value`: List<TelephonyChannelResourceApiConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.apiConfigurations = mapped
    }

    /**
     * @param argument The list of Telephony api configuration
     */
    @JvmName("ukncmyigvrvdenud")
    public suspend
    fun apiConfigurations(argument: List<suspend TelephonyChannelResourceApiConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TelephonyChannelResourceApiConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.apiConfigurations = mapped
    }

    /**
     * @param argument The list of Telephony api configuration
     */
    @JvmName("alxojnprbotwbhri")
    public suspend fun apiConfigurations(
        vararg
        argument: suspend TelephonyChannelResourceApiConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TelephonyChannelResourceApiConfigurationArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.apiConfigurations = mapped
    }

    /**
     * @param argument The list of Telephony api configuration
     */
    @JvmName("vjenyopdqsjiesbu")
    public suspend
    fun apiConfigurations(argument: suspend TelephonyChannelResourceApiConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            TelephonyChannelResourceApiConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.apiConfigurations = mapped
    }

    /**
     * @param values The list of Telephony api configuration
     */
    @JvmName("egfbbfaqeidijdse")
    public suspend fun apiConfigurations(
        vararg
        values: TelephonyChannelResourceApiConfigurationArgs,
    ) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.apiConfigurations = mapped
    }

    /**
     * @param value The extensionKey2
     */
    @JvmName("lonjauxdmwcjuxyi")
    public suspend fun cognitiveServiceRegion(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cognitiveServiceRegion = mapped
    }

    /**
     * @param value The extensionKey1
     */
    @JvmName("ywutqmegpkkdgpqq")
    public suspend fun cognitiveServiceSubscriptionKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cognitiveServiceSubscriptionKey = mapped
    }

    /**
     * @param value The default locale of the channel
     */
    @JvmName("akevttemyrklsluk")
    public suspend fun defaultLocale(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.defaultLocale = mapped
    }

    /**
     * @param value Whether the channel is enabled
     */
    @JvmName("ctpqqjhadawdargu")
    public suspend fun isEnabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEnabled = mapped
    }

    /**
     * @param value The list of Telephony phone numbers
     */
    @JvmName("fssgcagtgfppmvgw")
    public suspend fun phoneNumbers(`value`: List<TelephonyPhoneNumbersArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.phoneNumbers = mapped
    }

    /**
     * @param argument The list of Telephony phone numbers
     */
    @JvmName("uykifkouhantpigd")
    public suspend
    fun phoneNumbers(argument: List<suspend TelephonyPhoneNumbersArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            TelephonyPhoneNumbersArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.phoneNumbers = mapped
    }

    /**
     * @param argument The list of Telephony phone numbers
     */
    @JvmName("skhffjhuvuvabjek")
    public suspend fun phoneNumbers(
        vararg
        argument: suspend TelephonyPhoneNumbersArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            TelephonyPhoneNumbersArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.phoneNumbers = mapped
    }

    /**
     * @param argument The list of Telephony phone numbers
     */
    @JvmName("fjaxkgqmulobvuwq")
    public suspend fun phoneNumbers(argument: suspend TelephonyPhoneNumbersArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(TelephonyPhoneNumbersArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.phoneNumbers = mapped
    }

    /**
     * @param values The list of Telephony phone numbers
     */
    @JvmName("ijnjofosyllslbsw")
    public suspend fun phoneNumbers(vararg values: TelephonyPhoneNumbersArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.phoneNumbers = mapped
    }

    /**
     * @param value The premium SKU applied to the channel
     */
    @JvmName("ncdailsgpklovctd")
    public suspend fun premiumSKU(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.premiumSKU = mapped
    }

    internal fun build(): TelephonyChannelPropertiesArgs = TelephonyChannelPropertiesArgs(
        apiConfigurations = apiConfigurations,
        cognitiveServiceRegion = cognitiveServiceRegion,
        cognitiveServiceSubscriptionKey = cognitiveServiceSubscriptionKey,
        defaultLocale = defaultLocale,
        isEnabled = isEnabled,
        phoneNumbers = phoneNumbers,
        premiumSKU = premiumSKU,
    )
}
